@@ -33,13 +33,13 @@ pd.options.display.max_columns = 10
 ##############################################
 ### Parameters
 
-base_dir = os.path.realpath(os.path.dirname(__file__))
-
-with open(os.path.join(base_dir, 'parameters.yml')) as param:
-    param = yaml.safe_load(param)
-
-
-remotes_list = param['remotes']
+# base_dir = os.path.realpath(os.path.dirname(__file__))
+#
+# with open(os.path.join(base_dir, 'parameters.yml')) as param:
+#     param = yaml.safe_load(param)
+#
+#
+# remotes_list = param['remotes']
 
 ##############################################
 ### Class
@@ -278,65 +278,3 @@ class Tethys(object):
 # data1 = self.get_time_series_results(dataset_id, station_id, from_date='2012-01-02 00:00', output='Dataset')
 
 # data2 = self.bulk_time_series_results(dataset_id, site_ids, output='DataArray')
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
-
